@@ -54,6 +54,12 @@ module Sample : sig
 
   (** Clip a sample (ie ensure that it is between [-1.] and [1.]. *)
   val clip : t -> t
+
+  (** An IIR filter with given b coefficients. *)
+  val fir : float array -> t -> t
+
+  (** An IIR filter with given a and b coefficients. *)
+  val iir : float array -> float array -> t -> t
 end
 
 (** Operations on notes. *)
@@ -112,6 +118,29 @@ module Mono : sig
     int ->
     (float, Bigarray.float32_elt, Bigarray.c_layout) Bigarray.Array1.t
 
+  val copy_to_int16_ba :
+    t ->
+    int ->
+    int ->
+    (int, Bigarray.int16_signed_elt, Bigarray.c_layout) Bigarray.Array1.t ->
+    unit
+
+  val copy_from_int16_ba :
+    (int, Bigarray.int16_signed_elt, Bigarray.c_layout) Bigarray.Array1.t ->
+    t ->
+    int ->
+    int ->
+    unit
+
+  val of_int16_ba :
+    (int, Bigarray.int16_signed_elt, Bigarray.c_layout) Bigarray.Array1.t -> t
+
+  val to_int16_ba :
+    t ->
+    int ->
+    int ->
+    (int, Bigarray.int16_signed_elt, Bigarray.c_layout) Bigarray.Array1.t
+
   (** Length in samples. *)
   val length : t -> int
 
@@ -400,6 +429,30 @@ val to_ba :
   int ->
   (float, Bigarray.float32_elt, Bigarray.c_layout) Bigarray.Array1.t array
 
+val copy_to_int16_ba :
+  t ->
+  int ->
+  int ->
+  (int, Bigarray.int16_signed_elt, Bigarray.c_layout) Bigarray.Array1.t array ->
+  unit
+
+val copy_from_int16_ba :
+  (int, Bigarray.int16_signed_elt, Bigarray.c_layout) Bigarray.Array1.t array ->
+  t ->
+  int ->
+  int ->
+  unit
+
+val of_int16_ba :
+  (int, Bigarray.int16_signed_elt, Bigarray.c_layout) Bigarray.Array1.t array ->
+  t
+
+val to_int16_ba :
+  t ->
+  int ->
+  int ->
+  (int, Bigarray.int16_signed_elt, Bigarray.c_layout) Bigarray.Array1.t array
+
 (** Amplify a portion of the buffer by a given coefficient. *)
 val amplify : float -> t -> int -> int -> unit
 
@@ -434,17 +487,34 @@ module Ringbuffer : sig
   (** Create a ringbuffer of given number of channels and size (in samples). *)
   val create : int -> int -> t
 
+  (** Number of channels of the ringbuffr. *)
   val channels : t -> int
+
+  (** Number of samples available for reading. *)
   val read_space : t -> int
+
+  (** Number of samples available for writing. *)
   val write_space : t -> int
+
+  (** Advance the read pointer.*)
   val read_advance : t -> int -> unit
+
+  (** Advance the write pointer. *)
   val write_advance : t -> int -> unit
+
+  (** Fill in a buffer without changing read pointer. *)
   val peek : t -> buffer -> unit
+
+  (** Fill in a buffer and advance read pointer. *)
   val read : t -> buffer -> unit
+
+  (** Write a buffer into the ringbuffer. *)
   val write : t -> buffer -> unit
+
   val transmit : t -> (buffer -> int) -> int
 end
 
+(** Extensible ringbuffers.*)
 module Ringbuffer_ext : sig
   type t
 
@@ -462,6 +532,25 @@ end
 
 module Analyze : sig
   val rms : t -> int -> int -> float array
+
+  module ReplayGain : sig
+    type t
+
+    exception Not_supported
+
+    (** Create internal state for computing ReplayGain. Raises [Not_supported]
+        if the samplerate is not supported. *)
+    val create : channels:int -> samplerate:int -> t
+
+    (** Process a buffer. *)
+    val process : t -> buffer -> int -> int -> unit
+
+    (** Peak of processed samples. *)
+    val peak : t -> float
+
+    (** Replaygain for processed samples. *)
+    val gain : t -> float
+  end
 end
 
 (** Audio effects. *)
