@@ -33,6 +33,12 @@
 
 (** Operations on images. *)
 
+(** Trying to access a pixel outside the boundaries of the image. *)
+exception Invalid_position
+
+(** The image does not have the expected dimensions. *)
+exception Invalid_dimensions
+
 module Data : sig
   type t =
     (int, Bigarray.int8_unsigned_elt, Bigarray.c_layout) Bigarray.Array1.t
@@ -88,15 +94,10 @@ module Bitmap : sig
   type bitmap = t
 
   val create : int -> int -> t
-
   val width : t -> int
-
   val height : t -> int
-
   val get_pixel : t -> int -> int -> bool
-
   val set_pixel : t -> int -> int -> bool -> unit
-
   val scale : t -> t -> unit
 
   (** Operations on bitmap fonts. *)
@@ -125,6 +126,16 @@ module RGB8 : sig
 
     (** Decode a color stored as RGB. *)
     val of_int : int -> t
+
+    val to_int : t -> int
+  end
+end
+
+module ARGB8 : sig
+  module Color : sig
+    type t = int * RGB8.Color.t
+
+    val of_int : int -> t
   end
 end
 
@@ -375,6 +386,7 @@ module YUV420 : sig
   val get_pixel_y : t -> int -> int -> int
   val get_pixel_u : t -> int -> int -> int
   val get_pixel_v : t -> int -> int -> int
+  val get_pixel_a : t -> int -> int -> int
   val get_pixel_rgba : t -> int -> int -> Pixel.rgba
   val set_pixel_rgba : t -> int -> int -> Pixel.rgba -> unit
 
@@ -550,6 +562,9 @@ module Canvas (I : CanvasImage) : sig
   (** Size of a canvas in bytes. *)
   val size : t -> int
 
+  (** Number of planes in the image. *)
+  val planes : t -> int
+
   (** Add two canvas. The first one is on top of the second one. *)
   val add : t -> t -> t
 
